@@ -57,9 +57,15 @@ FT_BEGIN_HEADER
   /*************************************************************************/
 
 
+#ifndef HAVE_UNISTD_H
 #define HAVE_UNISTD_H
+#endif
+#ifndef HAVE_FCNTL_H
 #define HAVE_FCNTL_H
+#endif
+#ifndef HAVE_STDINT_H
 #define HAVE_STDINT_H
+#endif
 
 
   /* There are systems (like the Texas Instruments 'C54x) where a `char' */
