@@ -17,5 +17,7 @@
                              (OPENEXR_VERSION_MINOR << 16) | \
                              (OPENEXR_VERSION_PATCH <<  8))
 
+#ifndef __arm64__
 #define OPENEXR_IMF_HAVE_GCC_INLINE_ASM_AVX 1
+#endif
 #define OPENEXR_IMF_HAVE_SYSCONF_NPROCESSORS_ONLN 1
